#
# spec file for package bowtie
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           bowtie
Version:        1.3.1
Release:        1.6
Summary:        Fast and memory-efficient short read aligner
License:        Artistic-1.0
Group:          Productivity/Scientific/Other
URL:            http://bowtie-bio.sourceforge.net/index.shtml
Source:         https://github.com/BenLangmead/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  tbb-devel
BuildRequires:  pkgconfig(zlib)
ExclusiveArch:  x86_64 aarch64

%description
Bowtie is an ultrafast, memory-efficient short read aligner. It aligns short
DNA sequences (reads) to the human genome at a rate of over 25 million 35-bp
reads per hour. Bowtie indexes the genome with a Burrows-Wheeler index to keep
its memory footprint small: typically about 2.2 GB for the human genome
(2.9 GB for paired-end).

%prep
%autosetup -p1

%build
%make_build

%install
%make_install prefix=%{_prefix}
sed -i '1{s|^#!.*env python|#!%{_bindir}/python|}' %{buildroot}%{_bindir}/bowtie*

%files
%doc README MANUAL AUTHORS NEWS TUTORIAL VERSION
%license LICENSE
%{_bindir}/*

%changelog
* Wed May 18 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.3.1:
  + Fixed an overflow issue in `bowtie-build` that would sometimes
    yield corrupt "large" (64-bit) indexes; the resulting index
    would sometimes cause `bowtie` to hang. Note: `bowtie2-build`
    does not have this issue.
  + Fixed an issue in `bowtie` causing XM:i SAM optional field to
    sometimes be off by 1 when using the `-m/-M` flags.
  + Fixed an issue that would sometimes cause deadlocks in `bowtie`
    when running multithreaded.
  + Fixed an issue causing build errors when compiling against
    a pre-C++11 standard.
* Thu Apr 22 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Fixed SPEC file: Replaced broken URL
* Mon Sep 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.3.0:
  * Fixed an issue causing bowtie to report incorrect results
    when using a Bowtie 2 index.
  * New, more efficient implementation of --reorder for
    keeping SAM output lines in same order as input reads
  * Added -x parameter for specifying index. bowtie still
    supports specifying an index via positional parameter,
    but this behavior will be deprecated.
  * Migrated python scripts to python3.
  * Fully removed colorspace functionality.
  * Added support for compiling on ARM architectures.
  * Fixed an issue preventing bowtie from outputting newlines
    in --max and --un output files.
  * Fixed an issue causing alignment results to vary based
    on read names.
  * Fixed an issue preventing --no-unal from suppressing
    unmapped reads.
  * Removed dependence on some third-party libraries,
    simplifying the code and improving portability.
  * Fix an issue preventing bowtie from running with
    many threads on big-endian machines.
- Spec cleanup
- Enable aarch64 and disable ppc* and s390x.
* Tue May 12 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- aarch64 is not yet supported on Bowtie1. See:
  https://github.com/BenLangmead/bowtie/pull/13
* Thu Nov  7 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.2.3:
  * Added support for reading and inspecting Bowtie 2 indexes.
    Bowtie 2 indexes can now be used with either Bowtie or Bowtie
    2.
  * Added support for building an index from a gzipped-compressed
    FASTA.
  * Fixed issue preventing bowtie from reporting repeated
    alignments when -M is specified.
  * Fixed issue with -F mode omitting final base of each read.
  * Fixed clipping of first letter of first read in batches after
    first.
  * Fixed an issue preventing bowtie wrapper script from finding
    indexes.
- New BuildRequires: tbb-devel.
- Fix env based hashbangs.
- Use %%%%license to install LICENSE.
- Only build on 64-bit, building on 32-bit is no longer supported.
* Thu May  5 2016 flyos@mailoo.org
- Initial release
